<?php
/*
Plugin Name: Manager for Icommon (Foxtrot Media Patched)
Plugin URI: http://wordpress.org/plugins/manager-for-icomoon/
Description: Manage your icomoon font easily - Patched by Foxtrot Media to not allow unauthenticated uploads
Version: 2.0.2
Author: Julien Crego
Author URI: http://dev.juliencrego.com/manager-for-icomoon/
Text Domain: managerforicomoon
*/

namespace managerForIcomoon ;

use Exception;

define('PLUGIN_NAME', 'Manager for Icomoon');
define('PLUGIN_NAME_SHORT', 'Icomoon');
define('PLUGIN_PATH', plugin_dir_path( __FILE__ ));
define('PLUGIN_SLUG', 'managerforicomoon');
define('PLUGIN_URL', plugin_dir_url( __FILE__ ));
define('ICO_DEFAULT_FOLDER', 'icomoon');
define('ICO_UPLOADS_FOLDER', 'manager-for-icomoon');
define('ICO_ZIP_DEFAULT', 'icomoon-default.zip'); 

$uploads_path = wp_upload_dir() ;
define('UPLOADS_PATH', $uploads_path['basedir'].'/');
define('UPLOADS_URL', $uploads_path['baseurl'].'/');

/* Constantes concatenees */
define('PLUGIN_FILE', PLUGIN_PATH.'managerforicomoon.php');
define('ICO_DEFAULT_PATH', PLUGIN_PATH.ICO_DEFAULT_FOLDER.'/') ;
define('ICO_DEFAULT_URL', PLUGIN_URL.ICO_DEFAULT_FOLDER.'/') ;
define('ICO_UPLOADS_PATH', UPLOADS_PATH.ICO_UPLOADS_FOLDER.'/');
define('ICO_UPLOADS_URL', UPLOADS_URL.ICO_UPLOADS_FOLDER.'/');

require 'class/options.class.php';
Options::init();

new Core();

class Core {

    private $plugin_version = false ;
    private $plugin_info = array();
    private $plugin_options = array();
    private $url_plugin_donate = 'https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=MURUC7JZG94RA&source=url';
    private $icomoon_website = 'https://icomoon.io/';
    private $icomoon_website_doc_save_load = 'https://icomoon.io/#docs/save-load';
    private $shortcode_atts = false ;
    private $icons_list = array();


    static private $icomoon_url ;
    static private $icomoon_path ;
    static private $icomoon_custom ;
    
    public function __construct() {
        self::setIcomoonUrlAndPath();

        require 'class/plugin.class.php';
        new Plugin();

        if (!is_admin()) {
            add_shortcode(Options::get('shortcode'), array($this,'shortcodeLauncher') ); 
            add_filter('widget_text', 'do_shortcode');
        } else {
            require 'class/notice.class.php';

            /* Get Plugin info for version number */
            if( !function_exists('get_plugin_data') ){
                require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
            }
            $this->plugin_info = get_plugin_data(__FILE__) ;
            $this->plugin_version = $this->plugin_info['Version'];
            
            require 'class/settings.class.php';
            new Settings ;
            
            add_action('admin_menu', array( $this,'menu_page_init'));


            // Icomoon archive management
            add_action( 'plugins_loaded', function() {
                if (current_user_can('edit_files')) {
                    if (isset($_POST['managerforicomoon-upload'])) {
                        require 'class/zipPack.class.php';
                        ZipPack::upload();
                    }
                    if (isset($_POST['managerforicomoon-minify'])) {
                        require 'class/zipPack.class.php';
                        ZipPack::minifyCSS();
                    }
        
                    if (isset($_POST['managerforicomoon-restore'])) {
                        require 'class/zipPack.class.php';
                        ZipPack::restoreDefault();
                    }
                }
            });
            
            /* Gutenberg button */
            require 'class/gutenberg.class.php';
            new GutenbergButton();
            add_action('wp_ajax_nopriv_m4i_gutenberg_modal', array($this,'m4i_gutenberg_modal'));
            add_action('wp_ajax_m4i_gutenberg_modal', array($this,'m4i_gutenberg_modal'));
        }

        require 'class/scripts.class.php';
        new Scripts ;
    }

    static public function setIcomoonUrlAndPath(){
        if(file_exists(ICO_UPLOADS_PATH.'selection.json')){
            self::$icomoon_path = ICO_UPLOADS_PATH ;
            self::$icomoon_url = ICO_UPLOADS_URL ;
            self::$icomoon_custom = true ;
        } else {
            self::$icomoon_path = ICO_DEFAULT_PATH ;
            self::$icomoon_url = ICO_DEFAULT_URL ;
            self::$icomoon_custom = false ;
        }
    }

    static public function getIcomoonUrl(){
        return self::$icomoon_url ;
    }
    static public function getIcomoonPath(){
        return self::$icomoon_path ;
    }
    static public function isIcomoonCustom(){
        return self::$icomoon_custom ;
    }
    

    public function m4i_gutenberg_modal(){
        require 'html/page.modal.php' ;
        if(defined('DOING_AJAX') && DOING_AJAX) die();
    }

    /***************************************************************************
     * Backoffice pages
     **************************************************************************/
    
    public function menu_page_init() {
        add_menu_page( PLUGIN_NAME, PLUGIN_NAME_SHORT, 'edit_posts', PLUGIN_SLUG, array( $this,'html_page_home'), plugins_url('/img/logo_small.png', __FILE__ ));
        add_submenu_page(PLUGIN_SLUG, PLUGIN_NAME_SHORT.' | '.__( "Welcome", 'managerforicomoon'), __( "Welcome", 'managerforicomoon'), 'edit_posts',PLUGIN_SLUG, array( $this,'html_page_home'));
        add_submenu_page(PLUGIN_SLUG, PLUGIN_NAME_SHORT.' | '.__( "Upload ", 'managerforicomoon'), __( "Upload ", 'managerforicomoon'), 'administrator',PLUGIN_SLUG.'-zip', array( $this,'html_page_zip'));
        add_submenu_page(PLUGIN_SLUG, PLUGIN_NAME_SHORT.' | '.__( "Settings", 'managerforicomoon'), __( "Settings", 'managerforicomoon'), 'administrator',PLUGIN_SLUG.'-settings', array( $this,'html_page_settings'));
        add_submenu_page(PLUGIN_SLUG, PLUGIN_NAME_SHORT.' | '.__( "Icon list", 'managerforicomoon'), __( "Icon list", 'managerforicomoon'), 'edit_posts',PLUGIN_SLUG.'-icons', array( $this,'html_page_icons'));
        add_submenu_page(PLUGIN_SLUG, PLUGIN_NAME_SHORT.' | '.__( "Shortcode", 'managerforicomoon'), __( "Shortcode", 'managerforicomoon'), 'edit_posts',PLUGIN_SLUG.'-shortcode', array( $this,'html_page_shortcode'));
    }
    
    public function html_page_template($page){
        // Check files for all pages
        $this->getIcons();
        
        ob_start();
        require 'html/'.$page ;
        $content = ob_get_clean();

        ?>
        <div class="managerforicomoon">
            <header class="managerforicomoon-header">
                <div>
                    <h1><?php echo PLUGIN_NAME ;?></h1>
                    <span class="logo-header"></span>
                </div>
            </header> 

            <div class="managerforicomoon-page">
                <div class="managerforicomoon-content">
                    <div class="managerforicomoon-toast-container"><?php Notice::getToastHtml(); ?> </div>
                    <?php Notice::getHtml(); ?>     
                    <?= $content ?>
                </div>
            </div>

            <div class="managerforicomoon-donate">
                <p><?php echo __( "Version", 'managerforicomoon'); ?> <?php echo $this->plugin_version; ?> | 
                <strong><?php echo __( "Support the project", 'managerforicomoon'); ?></strong>
                <a class="button " href="<?php echo $this->url_plugin_donate;?>" target="_blank">
                    <?php echo __( "Donate", 'managerforicomoon'); ?>
                </a>

                <div class="logo-footer"></div>
            </div>
        </div>

        <?php
    }

    public function html_page_home() { 
        $this->html_page_template('page.home.php');
    }
    public function html_page_zip() {
        $this->html_page_template('page.zip.php');
    } 
    public function html_page_settings() {
        $this->html_page_template('page.settings.php');
    } 
    public function html_page_icons() {
        $this->html_page_template('page.icons.php');
    } 
    public function html_page_shortcode() {
        $this->html_page_template('page.shortcode.php');
    }
    

    

    /***************************************************************************
     * MISC METHODS
     **************************************************************************/
   
    public function shortcodeLauncher($atts){
        $this->shortcode_atts = shortcode_atts(array('name' => '','class'=>'','color'=>'','size'=>'','rotate'=>'','customcss'=>''), $atts);

        // Allow unprefixed name
        $icon_name = $this->shortcode_atts['name'];
        if(substr($icon_name, 0, strlen(Options::get('class_prefix'))) != Options::get('class_prefix')){
            $icon_name = Options::get('class_prefix').$icon_name ;
        }
        if(!$this->endsWith($icon_name, Options::get('class_postfix'))){
            $icon_name = $icon_name.Options::get('class_postfix') ;
        }
        
        switch(Options::get('css_selector')){
            case 'i':
                $markup = 'i';
                $class = '' ;
                break;
            case 'span':
                $markup = 'span';
                $class = '' ;
                break;
            case 'class':
                $markup = 'span';
                $class = Options::get('css_class').' ' ;
                break;
        }
 
        $style = "" ;
        if($this->shortcode_atts['color']){
            $style .= 'color:'.$this->shortcode_atts['color'].';';
        }
        if($this->shortcode_atts['size']){
            $style .= 'font-size:'.$this->shortcode_atts['size'].';';
        }
        if($this->shortcode_atts['rotate']){
            $rotate = intval($this->shortcode_atts['rotate']);
            $style .= 'display:inline-block;'
                    . '-webkit-transform: rotate('.$rotate.'deg); '
                    . '-ms-transform: rotate('.$rotate.'deg);'
                    . 'transform:rotate('.$rotate.'deg);';
        }
        if($this->shortcode_atts['customcss']){
            $style .= $this->shortcode_atts['customcss'] ;
        }
        ob_start();
        
        ?>
        <<?= $markup; ?> class="<?= $class.$icon_name ;?> <?php echo $this->shortcode_atts['class']; ?>"
        <?php if($style != "") { echo ' style="'.$style.'" ';} ?>
        ></<?= $markup; ?>>
        <?php
        return ob_get_clean();
    }

    function endsWith($haystack, $needle) {
        $length = strlen($needle);
        return $length > 0 ? substr($haystack, -$length) === $needle : true;
    }


    public function checkIcomoonFiles(){
        try {
            if(!file_exists(PLUGIN_PATH."icomoon/selection.json")) {
                throw new \Exception(__("The selection.json file is missing!", 'managerforicomoon'));
            }
            if(!is_readable(PLUGIN_PATH."icomoon/selection.json")) {
                throw new \Exception(__("The selection.json file is missing or is unreadable!", 'managerforicomoon'));
            } 
            if(!file_exists(PLUGIN_PATH."icomoon/style.css")) {
                throw new \Exception(__("The style.css file is missing!", 'managerforicomoon'));
            }
        } catch (\Exception $ex) {
            throw new \Exception('<b>'.$ex->getMessage().'</b><br>'. __("Thank you for reuploading the icomoon archive or restore the default archive.", 'managerforicomoon'));
        }
    }


    public function getIcons(){

        try {
            if(!$this->icons_list) {  
                $this->checkIcomoonFiles();

                switch(Options::get('css_selector')){
                    case 'i':
                        $markup = 'i';
                        $class = '' ;
                        break;
                    case 'class':
                        $markup = 'span';
                        $class = Options::get('css_class').' ' ;
                        break;
                    default:
                    case 'span':
                        $markup = 'span';
                        $class = '' ;
                        break;
                }

                $json_file = file_get_contents(self::getIcomoonPath()."selection.json");
                $json_content = json_decode($json_file, true);

                $this->icons_list = array();
                foreach($json_content['icons'] as $icon){
                    $names = explode(',',$icon['properties']['name']);
                    $name = trim($names[0]);
                    $this->icons_list[$name]['name'] = $name;
                    $this->icons_list[$name]['name-full'] = Options::get('class_prefix').$name;
                    $this->icons_list[$name]['icon'] = '<'.$markup.' class="'.$class.Options::get('class_prefix').$name.Options::get('class_postfix').'"></'.$markup.'>'; 
                    $this->icons_list[$name]['shortcode'] = '['.Options::get('shortcode').' name="'.$name.'"]';              
                }
                if(count($this->icons_list)<1){
                    throw new \Exception('<b>'.__( "The Icomoon package does not contain any icons.", 'managerforicomoon').'</b><br>'. __("Thank you for reuploading the icomoon archive or restore the default archive.", 'managerforicomoon'));
                }
            }

            return $this->icons_list ;
        } catch (\Exception $ex) {
            Notice::setError($ex->getMessage());
        }
    }
}

